@@ -1,9 +1,11 @@
+-- Deprecated since 3.1.6. Use pgroonga_condition instead.
 CREATE TYPE pgroonga_full_text_search_condition AS (
 	query text,
 	weigths int[],
 	indexName text
 );
 
+-- Deprecated since 3.1.6. Use pgroonga_condition instead.
 CREATE TYPE pgroonga_full_text_search_condition_with_scorers AS (
 	query text,
 	weigths int[],
@@ -11,6 +13,40 @@ CREATE TYPE pgroonga_full_text_search_condition_with_scorers AS (
 	indexName text
 );
 
+CREATE TYPE pgroonga_condition AS (
+	query text,
+	weigths int[],
+	scorers text[],
+	schema_name text,
+	index_name text,
+	column_name text,
+	fuzzy_max_distance_ratio float4
+);
+
+CREATE FUNCTION pgroonga_condition(query text = null,
+				   weights int[] = null,
+				   scorers text[] = null,
+				   schema_name text = null,
+				   index_name text = null,
+				   column_name text = null,
+				   fuzzy_max_distance_ratio float4 = null)
+	RETURNS pgroonga_condition
+	LANGUAGE SQL
+	AS $$
+		SELECT (
+			query,
+			weights,
+			scorers,
+			schema_name,
+			index_name,
+			column_name,
+			fuzzy_max_distance_ratio
+		)::pgroonga_condition
+	$$
+	IMMUTABLE
+	LEAKPROOF
+	PARALLEL SAFE;
+
 CREATE FUNCTION pgroonga_score("row" record)
 	RETURNS float8
 	AS 'MODULE_PATHNAME', 'pgroonga_score_row'
@@ -401,6 +437,52 @@ CREATE FUNCTION pgroonga_wal_set_applied_position()
 	LANGUAGE C
 	STRICT;
 
+DO LANGUAGE plpgsql $$
+DECLARE
+	rec record;
+BEGIN
+	-- A column in pg_stat_wal_receiver is different for 12 and 13 or higher.
+	--* received_lsn: 12
+	--* flushed_lsn: 13 or higher
+	SELECT * INTO STRICT rec from pg_settings WHERE name = 'server_version';
+	IF SUBSTR(rec.setting, 1, 2) >= '13' THEN
+		CREATE FUNCTION pgroonga_list_lagged_indexes()
+			RETURNS SETOF text AS '
+				SELECT name FROM pgroonga_wal_status()
+				WHERE current_block != last_block
+					OR current_offset != current_offset
+					OR current_size != last_size
+					OR EXISTS(
+						SELECT 1 FROM pg_stat_wal_receiver
+						WHERE flushed_lsn != latest_end_lsn
+					);
+			' LANGUAGE SQL
+			STRICT
+			PARALLEL SAFE;
+	ELSE
+		CREATE FUNCTION pgroonga_list_lagged_indexes()
+			RETURNS SETOF text AS '
+				SELECT name FROM pgroonga_wal_status()
+				WHERE current_block != last_block
+					OR current_offset != current_offset
+					OR current_size != last_size
+					OR EXISTS(
+						SELECT 1 FROM pg_stat_wal_receiver
+						WHERE received_lsn != latest_end_lsn
+					);
+			' LANGUAGE SQL
+			STRICT
+			PARALLEL SAFE;
+	END IF;
+END;
+$$;
+
+CREATE FUNCTION pgroonga_list_broken_indexes()
+	RETURNS SETOF text
+	AS 'MODULE_PATHNAME', 'pgroonga_list_broken_indexes'
+	LANGUAGE C
+	STRICT
+	PARALLEL SAFE;
 
 /* v1 */
 CREATE FUNCTION pgroonga_match_term(target text, term text)
@@ -608,6 +690,25 @@ CREATE OPERATOR &@ (
 	JOIN = contjoinsel
 );
 
+CREATE FUNCTION pgroonga_match_text_condition
+	(target text, condition pgroonga_condition)
+	RETURNS bool
+	AS 'MODULE_PATHNAME', 'pgroonga_match_text_condition'
+	LANGUAGE C
+	IMMUTABLE
+	STRICT
+	LEAKPROOF
+	PARALLEL SAFE
+	COST 300;
+
+CREATE OPERATOR &@ (
+	PROCEDURE = pgroonga_match_text_condition,
+	LEFTARG = text,
+	RIGHTARG = pgroonga_condition,
+	RESTRICT = contsel,
+	JOIN = contjoinsel
+);
+
 CREATE FUNCTION pgroonga_match_text_array(text[], text)
 	RETURNS bool
 	AS 'MODULE_PATHNAME', 'pgroonga_match_text_array'
@@ -665,6 +766,25 @@ CREATE OPERATOR &@ (
 	JOIN = contjoinsel
 );
 
+CREATE FUNCTION pgroonga_match_text_array_condition
+	(target text[], condition pgroonga_condition)
+	RETURNS bool
+	AS 'MODULE_PATHNAME', 'pgroonga_match_text_array_condition'
+	LANGUAGE C
+	IMMUTABLE
+	STRICT
+	LEAKPROOF
+	PARALLEL SAFE
+	COST 300;
+
+CREATE OPERATOR &@ (
+	PROCEDURE = pgroonga_match_text_array_condition,
+	LEFTARG = text[],
+	RIGHTARG = pgroonga_condition,
+	RESTRICT = contsel,
+	JOIN = contjoinsel
+);
+
 CREATE FUNCTION pgroonga_match_varchar(varchar, varchar)
 	RETURNS bool
 	AS 'MODULE_PATHNAME', 'pgroonga_match_varchar'
@@ -722,6 +842,25 @@ CREATE OPERATOR &@ (
 	JOIN = contjoinsel
 );
 
+CREATE FUNCTION pgroonga_match_varchar_condition
+	(target varchar, condition pgroonga_condition)
+	RETURNS bool
+	AS 'MODULE_PATHNAME', 'pgroonga_match_varchar_condition'
+	LANGUAGE C
+	IMMUTABLE
+	STRICT
+	LEAKPROOF
+	PARALLEL SAFE
+	COST 300;
+
+CREATE OPERATOR &@ (
+	PROCEDURE = pgroonga_match_varchar_condition,
+	LEFTARG = varchar,
+	RIGHTARG = pgroonga_condition,
+	RESTRICT = contsel,
+	JOIN = contjoinsel
+);
+
 CREATE FUNCTION pgroonga_contain_varchar_array(varchar[], varchar)
 	RETURNS bool
 	AS 'MODULE_PATHNAME', 'pgroonga_contain_varchar_array'
@@ -824,6 +963,25 @@ CREATE OPERATOR &@~ (
 	JOIN = contjoinsel
 );
 
+CREATE FUNCTION pgroonga_query_text_condition
+	(target text, condition pgroonga_condition)
+	RETURNS bool
+	AS 'MODULE_PATHNAME', 'pgroonga_query_text_condition'
+	LANGUAGE C
+	IMMUTABLE
+	STRICT
+	LEAKPROOF
+	PARALLEL SAFE
+	COST 300;
+
+CREATE OPERATOR &@~ (
+	PROCEDURE = pgroonga_query_text_condition,
+	LEFTARG = text,
+	RIGHTARG = pgroonga_condition,
+	RESTRICT = contsel,
+	JOIN = contjoinsel
+);
+
 CREATE FUNCTION pgroonga_query_text_array(text[], text)
 	RETURNS bool
 	AS 'MODULE_PATHNAME', 'pgroonga_query_text_array'
@@ -890,6 +1048,25 @@ CREATE OPERATOR &@~ (
 	JOIN = contjoinsel
 );
 
+CREATE FUNCTION pgroonga_query_text_array_condition
+	(targets text[], condition pgroonga_condition)
+	RETURNS bool
+	AS 'MODULE_PATHNAME', 'pgroonga_query_text_array_condition'
+	LANGUAGE C
+	IMMUTABLE
+	STRICT
+	LEAKPROOF
+	PARALLEL SAFE
+	COST 300;
+
+CREATE OPERATOR &@~ (
+	PROCEDURE = pgroonga_query_text_array_condition,
+	LEFTARG = text[],
+	RIGHTARG = pgroonga_condition,
+	RESTRICT = contsel,
+	JOIN = contjoinsel
+);
+
 CREATE FUNCTION pgroonga_query_varchar(varchar, varchar)
 	RETURNS bool
 	AS 'MODULE_PATHNAME', 'pgroonga_query_varchar'
@@ -956,6 +1133,25 @@ CREATE OPERATOR &@~ (
 	JOIN = contjoinsel
 );
 
+CREATE FUNCTION pgroonga_query_varchar_condition
+	(target varchar, condition pgroonga_condition)
+	RETURNS bool
+	AS 'MODULE_PATHNAME', 'pgroonga_query_varchar_condition'
+	LANGUAGE C
+	IMMUTABLE
+	STRICT
+	LEAKPROOF
+	PARALLEL SAFE
+	COST 300;
+
+CREATE OPERATOR &@~ (
+	PROCEDURE = pgroonga_query_varchar_condition,
+	LEFTARG = varchar,
+	RIGHTARG = pgroonga_condition,
+	RESTRICT = contsel,
+	JOIN = contjoinsel
+);
+
 CREATE FUNCTION pgroonga_query_jsonb(jsonb, text)
 	RETURNS bool
 	AS 'MODULE_PATHNAME', 'pgroonga_query_jsonb'
@@ -1101,6 +1297,25 @@ CREATE OPERATOR &^ (
 	JOIN = contjoinsel
 );
 
+CREATE FUNCTION pgroonga_prefix_text_condition
+	(text, condition pgroonga_condition)
+	RETURNS bool
+	AS 'MODULE_PATHNAME', 'pgroonga_prefix_text_condition'
+	LANGUAGE C
+	IMMUTABLE
+	STRICT
+	LEAKPROOF
+	PARALLEL SAFE
+	COST 300;
+
+CREATE OPERATOR &^ (
+	PROCEDURE = pgroonga_prefix_text_condition,
+	LEFTARG = text,
+	RIGHTARG = pgroonga_condition,
+	RESTRICT = contsel,
+	JOIN = contjoinsel
+);
+
 CREATE FUNCTION pgroonga_prefix_text_array(text[], text)
 	RETURNS bool
 	AS 'MODULE_PATHNAME', 'pgroonga_prefix_text_array'
@@ -1119,6 +1334,24 @@ CREATE OPERATOR &^ (
 	JOIN = contjoinsel
 );
 
+CREATE FUNCTION pgroonga_prefix_text_array_condition(text[], pgroonga_condition)
+	RETURNS bool
+	AS 'MODULE_PATHNAME', 'pgroonga_prefix_text_array_condition'
+	LANGUAGE C
+	IMMUTABLE
+	STRICT
+	LEAKPROOF
+	PARALLEL SAFE
+	COST 300;
+
+CREATE OPERATOR &^ (
+	PROCEDURE = pgroonga_prefix_text_array_condition,
+	LEFTARG = text[],
+	RIGHTARG = pgroonga_condition,
+	RESTRICT = contsel,
+	JOIN = contjoinsel
+);
+
 /* Deprecated since 1.2.1. */
 CREATE OPERATOR &^> (
 	PROCEDURE = pgroonga_prefix_text_array,
@@ -1165,6 +1398,25 @@ CREATE OPERATOR &^ (
 	JOIN = contjoinsel
 );
 
+CREATE FUNCTION pgroonga_prefix_varchar_condition
+	(target varchar, conditoin pgroonga_condition)
+	RETURNS bool
+	AS 'MODULE_PATHNAME', 'pgroonga_prefix_varchar_condition'
+	LANGUAGE C
+	IMMUTABLE
+	STRICT
+	LEAKPROOF
+	PARALLEL SAFE
+	COST 300;
+
+CREATE OPERATOR &^ (
+	PROCEDURE = pgroonga_prefix_varchar_condition,
+	LEFTARG = varchar,
+	RIGHTARG = pgroonga_condition,
+	RESTRICT = contsel,
+	JOIN = contjoinsel
+);
+
 CREATE FUNCTION pgroonga_prefix_varchar_array(varchar[], varchar)
 	RETURNS bool
 	AS 'MODULE_PATHNAME', 'pgroonga_prefix_varchar_array'
@@ -1183,6 +1435,24 @@ CREATE OPERATOR &^ (
 	JOIN = contjoinsel
 );
 
+CREATE FUNCTION pgroonga_prefix_varchar_array_condition(varchar[], pgroonga_condition)
+	RETURNS bool
+	AS 'MODULE_PATHNAME', 'pgroonga_prefix_varchar_array_condition'
+	LANGUAGE C
+	IMMUTABLE
+	STRICT
+	LEAKPROOF
+	PARALLEL SAFE
+	COST 300;
+
+CREATE OPERATOR &^ (
+	PROCEDURE = pgroonga_prefix_varchar_array_condition,
+	LEFTARG = varchar[],
+	RIGHTARG = pgroonga_condition,
+	RESTRICT = contsel,
+	JOIN = contjoinsel
+);
+
 /* Deprecated since 1.2.1. */
 CREATE OPERATOR &^> (
 	PROCEDURE = pgroonga_prefix_varchar_array,
@@ -1779,6 +2049,25 @@ CREATE OPERATOR &= (
 	JOIN = contjoinsel
 );
 
+CREATE FUNCTION pgroonga_equal_text_condition
+	(target text, condition pgroonga_condition)
+	RETURNS bool
+	AS 'MODULE_PATHNAME', 'pgroonga_equal_text_condition'
+	LANGUAGE C
+	IMMUTABLE
+	STRICT
+	LEAKPROOF
+	PARALLEL SAFE
+	COST 300;
+
+CREATE OPERATOR &= (
+	PROCEDURE = pgroonga_equal_text_condition,
+	LEFTARG = text,
+	RIGHTARG = pgroonga_condition,
+	RESTRICT = contsel,
+	JOIN = contjoinsel
+);
+
 CREATE FUNCTION pgroonga_equal_varchar(target varchar, other varchar)
 	RETURNS bool
 	AS 'MODULE_PATHNAME', 'pgroonga_equal_varchar'
@@ -1816,6 +2105,25 @@ CREATE OPERATOR &= (
 	JOIN = contjoinsel
 );
 
+CREATE FUNCTION pgroonga_equal_varchar_condition
+	(target varchar, condition pgroonga_condition)
+	RETURNS bool
+	AS 'MODULE_PATHNAME', 'pgroonga_equal_text_condition'
+	LANGUAGE C
+	IMMUTABLE
+	STRICT
+	LEAKPROOF
+	PARALLEL SAFE
+	COST 300;
+
+CREATE OPERATOR &= (
+	PROCEDURE = pgroonga_equal_varchar_condition,
+	LEFTARG = varchar,
+	RIGHTARG = pgroonga_condition,
+	RESTRICT = contsel,
+	JOIN = contjoinsel
+);
+
 CREATE FUNCTION pgroonga_equal_query_text_array(targets text[], query text)
 	RETURNS bool
 	AS 'MODULE_PATHNAME', 'pgroonga_equal_query_text_array'
@@ -1834,6 +2142,44 @@ CREATE OPERATOR &=~ (
 	JOIN = contjoinsel
 );
 
+CREATE FUNCTION pgroonga_equal_query_text_array_condition
+	(targets text[], condition pgroonga_full_text_search_condition)
+	RETURNS bool
+	AS 'MODULE_PATHNAME', 'pgroonga_equal_query_text_array_condition'
+	LANGUAGE C
+	IMMUTABLE
+	STRICT
+	LEAKPROOF
+	PARALLEL SAFE
+	COST 300;
+
+CREATE OPERATOR &=~ (
+	PROCEDURE = pgroonga_equal_query_text_array_condition,
+	LEFTARG = text[],
+	RIGHTARG = pgroonga_full_text_search_condition,
+	RESTRICT = contsel,
+	JOIN = contjoinsel
+);
+
+CREATE FUNCTION pgroonga_equal_query_text_array_condition
+	(targets text[], condition pgroonga_condition)
+	RETURNS bool
+	AS 'MODULE_PATHNAME', 'pgroonga_equal_query_text_array_condition'
+	LANGUAGE C
+	IMMUTABLE
+	STRICT
+	LEAKPROOF
+	PARALLEL SAFE
+	COST 300;
+
+CREATE OPERATOR &=~ (
+	PROCEDURE = pgroonga_equal_query_text_array_condition,
+	LEFTARG = text[],
+	RIGHTARG = pgroonga_condition,
+	RESTRICT = contsel,
+	JOIN = contjoinsel
+);
+
 CREATE FUNCTION pgroonga_equal_query_varchar_array(targets varchar[], query text)
 	RETURNS bool
 	AS 'MODULE_PATHNAME', 'pgroonga_equal_query_varchar_array'
@@ -1852,6 +2198,44 @@ CREATE OPERATOR &=~ (
 	JOIN = contjoinsel
 );
 
+CREATE FUNCTION pgroonga_equal_query_varchar_array_condition
+	(targets varchar[], condition pgroonga_full_text_search_condition)
+	RETURNS bool
+	AS 'MODULE_PATHNAME', 'pgroonga_equal_query_varchar_array_condition'
+	LANGUAGE C
+	IMMUTABLE
+	STRICT
+	LEAKPROOF
+	PARALLEL SAFE
+	COST 300;
+
+CREATE OPERATOR &=~ (
+	PROCEDURE = pgroonga_equal_query_varchar_array_condition,
+	LEFTARG = varchar[],
+	RIGHTARG = pgroonga_full_text_search_condition,
+	RESTRICT = contsel,
+	JOIN = contjoinsel
+);
+
+CREATE FUNCTION pgroonga_equal_query_varchar_array_condition
+	(targets varchar[], condition pgroonga_condition)
+	RETURNS bool
+	AS 'MODULE_PATHNAME', 'pgroonga_equal_query_varchar_array_condition'
+	LANGUAGE C
+	IMMUTABLE
+	STRICT
+	LEAKPROOF
+	PARALLEL SAFE
+	COST 300;
+
+CREATE OPERATOR &=~ (
+	PROCEDURE = pgroonga_equal_query_varchar_array_condition,
+	LEFTARG = varchar[],
+	RIGHTARG = pgroonga_condition,
+	RESTRICT = contsel,
+	JOIN = contjoinsel
+);
+
 
 DROP ACCESS METHOD IF EXISTS pgroonga CASCADE;
 CREATE FUNCTION pgroonga_handler(internal)
@@ -2036,10 +2420,17 @@ CREATE OPERATOR CLASS pgroonga_text_full_text_search_ops_v2
 		OPERATOR 28 &@~,
 		OPERATOR 29 &@*,
 		OPERATOR 30 &@~| (text, text[]),
+		-- For backward compatibility
 		OPERATOR 31 &@ (text, pgroonga_full_text_search_condition),
+		-- For backward compatibility
 		OPERATOR 32 &@~ (text, pgroonga_full_text_search_condition),
+		-- For backward compatibility
 		OPERATOR 33 &@ (text, pgroonga_full_text_search_condition_with_scorers),
-		OPERATOR 34 &@~ (text, pgroonga_full_text_search_condition_with_scorers);
+		-- For backward compatibility
+		OPERATOR 34 &@~ (text, pgroonga_full_text_search_condition_with_scorers),
+		OPERATOR 42 &@ (text, pgroonga_condition),
+		OPERATOR 43 &@~ (text, pgroonga_condition);
+
 
 CREATE OPERATOR CLASS pgroonga_text_array_full_text_search_ops_v2
 	DEFAULT FOR TYPE text[]
@@ -2055,10 +2446,16 @@ CREATE OPERATOR CLASS pgroonga_text_array_full_text_search_ops_v2
 		OPERATOR 28 &@~ (text[], text),
 		OPERATOR 29 &@* (text[], text),
 		OPERATOR 30 &@~| (text[], text[]),
+		-- For backward compatibility
 		OPERATOR 31 &@ (text[], pgroonga_full_text_search_condition),
+		-- For backward compatibility
 		OPERATOR 32 &@~ (text[], pgroonga_full_text_search_condition),
+		-- For backward compatibility
 		OPERATOR 33 &@ (text[], pgroonga_full_text_search_condition_with_scorers),
-		OPERATOR 34 &@~ (text[], pgroonga_full_text_search_condition_with_scorers);
+		-- For backward compatibility
+		OPERATOR 34 &@~ (text[], pgroonga_full_text_search_condition_with_scorers),
+		OPERATOR 42 &@ (text[], pgroonga_condition),
+		OPERATOR 43 &@~ (text[], pgroonga_condition);
 
 CREATE OPERATOR CLASS pgroonga_text_term_search_ops_v2 FOR TYPE text
 	USING pgroonga AS
@@ -2072,9 +2469,13 @@ CREATE OPERATOR CLASS pgroonga_text_term_search_ops_v2 FOR TYPE text
 		OPERATOR 20 &^| (text, text[]),
 		OPERATOR 21 &^~| (text, text[]),
 		OPERATOR 36 !&^| (text, text[]),
+		-- For backward compatibility
 		OPERATOR 37 &^ (text, pgroonga_full_text_search_condition),
 		OPERATOR 38 &=,
-		OPERATOR 39 &= (text, pgroonga_full_text_search_condition);
+		-- For backward compatibility
+		OPERATOR 39 &= (text, pgroonga_full_text_search_condition),
+		OPERATOR 44 &^ (text, pgroonga_condition),
+		OPERATOR 45 &= (text, pgroonga_condition);
 
 CREATE OPERATOR CLASS pgroonga_text_array_term_search_ops_v2 FOR TYPE text[]
 	USING pgroonga AS
@@ -2085,7 +2486,11 @@ CREATE OPERATOR CLASS pgroonga_text_array_term_search_ops_v2 FOR TYPE text[]
 		OPERATOR 21 &^~| (text[], text[]),
 		OPERATOR 24 &^> (text[], text), -- For backward compatibility
 		OPERATOR 25 &^~> (text[], text), -- For backward compatibility
-		OPERATOR 40 &=~ (text[], text);
+		OPERATOR 40 &=~ (text[], text),
+		-- For backward compatibility
+		OPERATOR 41 &=~ (text[], pgroonga_full_text_search_condition),
+		OPERATOR 44 &^ (text[], pgroonga_condition),
+		OPERATOR 46 &=~ (text[], pgroonga_condition);
 
 CREATE OPERATOR CLASS pgroonga_text_regexp_ops_v2 FOR TYPE text
 	USING pgroonga AS
@@ -2107,9 +2512,13 @@ CREATE OPERATOR CLASS pgroonga_varchar_term_search_ops_v2
 		OPERATOR 17 &^~,
 		OPERATOR 20 &^| (varchar, varchar[]),
 		OPERATOR 21 &^~| (varchar, varchar[]),
+		-- For backward compatibility
 		OPERATOR 37 &^ (varchar, pgroonga_full_text_search_condition),
 		OPERATOR 38 &=,
-		OPERATOR 39 &= (varchar, pgroonga_full_text_search_condition);
+		-- For backward compatibility
+		OPERATOR 39 &= (varchar, pgroonga_full_text_search_condition),
+		OPERATOR 44 &^ (varchar, pgroonga_condition),
+		OPERATOR 45 &= (varchar, pgroonga_condition);
 
 CREATE OPERATOR CLASS pgroonga_varchar_full_text_search_ops_v2
 	FOR TYPE varchar
@@ -2125,10 +2534,16 @@ CREATE OPERATOR CLASS pgroonga_varchar_full_text_search_ops_v2
 		OPERATOR 28 &@~,
 		OPERATOR 29 &@*,
 		OPERATOR 30 &@~| (varchar, varchar[]),
+		-- For backward compatibility
 		OPERATOR 31 &@ (varchar, pgroonga_full_text_search_condition),
+		-- For backward compatibility
 		OPERATOR 32 &@~ (varchar, pgroonga_full_text_search_condition),
+		-- For backward compatibility
 		OPERATOR 33 &@ (varchar, pgroonga_full_text_search_condition_with_scorers),
-		OPERATOR 34 &@~ (varchar, pgroonga_full_text_search_condition_with_scorers);
+		-- For backward compatibility
+		OPERATOR 34 &@~ (varchar, pgroonga_full_text_search_condition_with_scorers),
+		OPERATOR 42 &@ (varchar, pgroonga_condition),
+		OPERATOR 43 &@~ (varchar, pgroonga_condition);
 
 CREATE OPERATOR CLASS pgroonga_varchar_array_term_search_ops_v2
 	DEFAULT FOR TYPE varchar[]
@@ -2142,7 +2557,11 @@ CREATE OPERATOR CLASS pgroonga_varchar_array_term_search_ops_v2
 		OPERATOR 23 &> (varchar[], varchar),
 		OPERATOR 24 &^> (varchar[], varchar), -- For backward compatibility
 		OPERATOR 25 &^~> (varchar[], varchar), -- For backward compatibility
-		OPERATOR 40 &=~ (varchar[], text);
+		OPERATOR 40 &=~ (varchar[], text),
+		-- For backward compatibility
+		OPERATOR 41 &=~ (varchar[], pgroonga_full_text_search_condition),
+		OPERATOR 44 &^ (varchar[], pgroonga_condition),
+		OPERATOR 46 &=~ (varchar[], pgroonga_condition);
 
 CREATE OPERATOR CLASS pgroonga_varchar_regexp_ops_v2 FOR TYPE varchar
 	USING pgroonga AS
@@ -2167,6 +2586,7 @@ CREATE OPERATOR CLASS pgroonga_jsonb_full_text_search_ops_v2
 		OPERATOR 28 &@~ (jsonb, text);
 
 -- For backward compatibility
+-- TODO: We must remove this when we release 4.0.0.
 
 DO LANGUAGE plpgsql $$
 BEGIN
